# typetype
A Command Line Typing Game by Ahmet Ozer

## Installation
To install typetype, use the following command:
 `pip install typetype`


## Usage
To start playing the game, simply run:
`typetype`

## Cursor Option
To use the custom '|' cursor that I made, run the game with the `-cursor` option.

## About
`typetype` is a minimalistic command line typing game. I made this game becuase I couldn't find any command line typing games that I liked, so I decided to make one myself. I made this game in 1 week and worked on it during my trip to canada. Since it is a minimalistic game, I did not include much text/instructions. In order to see the game's unwritten controls please read the Navigation section before playing the game.

## Controls
Please read the following instructions to familiarize yourself with the game's controls before playing:

### Mode Selection Pages:
- Use the arrow keys to navigate and select different game modes.
- Press the Enter key to confirm the selected mode.
- Press the Delete key to go back to the previous game.
- Press the Esc key to quit the game (only applicable on the first page).

### Inside The Game:
- Simply start typing to play the game!
- Press the Esc key to restart the game.
- If the timer hasn't started yet, press * to return to the menu.

### Results/End Page:
- Use the Esc key to quit the game.


